==> layout_builder_simplify-1.0.1.tar.gz: layout_builder_simplify/js/layout_builder_simplify.search.js <==
/**
 * @file
 * Contains layout builder simplify js.
 */
(function ($, Drupal) {
  /**
   * Implements JS to handle custom block content search.
   */
  Drupal.behaviors.searchBlocks = {
    attach: function(context) {
      'use strict';
      // Added current region request data.
      $(".layout-builder__link--add").click(function () {
        var result = $(this).attr('href').split('/');
        localStorage.setItem("Drupal.layout_builder.node", result[5]);
        localStorage.setItem("Drupal.layout_builder.delta", result[6]);
        localStorage.setItem("Drupal.layout_builder.region", result[7]);
      });

      $('.custom.js-layout-builder-filter').flexdatalist({
        keyword: 'search',
        minLength: 1,
        searchContain: true,
        searchIn: 'title',
        url: '/block-search.json',
        cache: false,
        requestType: "POST",
        searchDelay: 200,
        noResultsText: 'The <em>{keyword}</em> return no results.'
      });

      $('.custom.js-layout-builder-filter').on('show:flexdatalist.results', function(event, result) {
        var list = '<ul class="inline-block-list links">';
        var r = localStorage.getItem('Drupal.layout_builder.region');
        var d = localStorage.getItem('Drupal.layout_builder.delta');
        var n = localStorage.getItem('Drupal.layout_builder.node');
        $.each(result, function( index, value ) {
          var link = '/layout_builder/add/block/overrides/' + n +  '/' + d + '/' + r +  '/block_content%3A' + value.uuid;
          list = list + '<li class="_"><a href="' + link + '" class="use-ajax js-layout-builder-block-link inline-block-list__item" data-dialog-type="dialog" data-dialog-renderer="off_canvas">' + value.title + ' [' + value.type + ']</a></li>';
        });
        list = list + '</ul>';
        $('.js-layout-builder-categories').html(list);
        Drupal.ajax.bindAjaxLinks(document.body);
      });

      $('.custom.js-layout-builder-filter').on('change:flexdatalist', function(event, set, options) {
        $('.recently_updated').remove();
        $('.js-layout-builder-categories').html('');
      });

      $('.custom.js-layout-builder-filter').on('shown:flexdatalist.results', function(event, result) {
        $('.flexdatalist-results').remove();
      });
    }
  };
})(jQuery, Drupal);

==> layout_builder_simplify-1.0.2.tar.gz: layout_builder_simplify/js/layout_builder_simplify.search.js <==
/**
 * @file
 * Contains layout builder simplify js.
 */
(function ($, Drupal) {
  /**
   * Implements JS to handle custom block content search.
   */
  Drupal.behaviors.searchBlocks = {
    attach: function(context) {
      'use strict';
      // Added current region request data.
      $(".layout-builder__link--add").click(function () {
        var pathPrefix = drupalSettings.path.pathPrefix.replace('/','');
        var result = $(this).attr('href').split('/');
        if (pathPrefix == result[1]) {
          localStorage.setItem("Drupal.layout_builder.node", result[6]);
          localStorage.setItem("Drupal.layout_builder.delta", result[7]);
          localStorage.setItem("Drupal.layout_builder.region", result[8]);
          localStorage.setItem("Drupal.layout_builder.language_prefix", pathPrefix);
        }
        else {
          localStorage.setItem("Drupal.layout_builder.node", result[5]);
          localStorage.setItem("Drupal.layout_builder.delta", result[6]);
          localStorage.setItem("Drupal.layout_builder.region", result[7]);
          localStorage.setItem("Drupal.layout_builder.language_prefix", null);
        }
      });

      $('.custom.js-layout-builder-filter').flexdatalist({
        keyword: 'search',
        minLength: 1,
        searchContain: true,
        searchIn: 'title',
        url: '/block-search.json',
        cache: false,
        requestType: "POST",
        searchDelay: 200,
        noResultsText: 'The <em>{keyword}</em> return no results.'
      });

      $('.custom.js-layout-builder-filter').on('show:flexdatalist.results', function(event, result) {
        var list = '<ul class="inline-block-list links">';
        var r = localStorage.getItem('Drupal.layout_builder.region');
        var d = localStorage.getItem('Drupal.layout_builder.delta');
        var n = localStorage.getItem('Drupal.layout_builder.node');
        $.each(result, function( index, value ) {
          if (localStorage.getItem('Drupal.layout_builder.language_prefix')) {
            var link = '/' + localStorage.getItem('Drupal.layout_builder.language_prefix') + '/layout_builder/add/block/overrides/' + n +  '/' + d + '/' + r +  '/block_content%3A' + value.uuid;
          }
          else {
            var link = 'layout_builder/add/block/overrides/' + n +  '/' + d + '/' + r +  '/block_content%3A' + value.uuid;
          }
          list = list + '<li class="_"><a href="' + link + '" class="use-ajax js-layout-builder-block-link inline-block-list__item" data-dialog-type="dialog" data-dialog-renderer="off_canvas">' + value.title + ' [' + value.type + ']</a></li>';
        });
        list = list + '</ul>';
        $('.js-layout-builder-categories').html(list);
        Drupal.ajax.bindAjaxLinks(document.body);
      });

      $('.custom.js-layout-builder-filter').on('change:flexdatalist', function(event, set, options) {
        $('.recently_updated').remove();
        $('.js-layout-builder-categories').html('');
      });

      $('.custom.js-layout-builder-filter').on('shown:flexdatalist.results', function(event, result) {
        $('.flexdatalist-results').remove();
      });
    }
  };
})(jQuery, Drupal);
